@@ -1,9 +1,11 @@
 # Created with:
 # methods::getGenerics(asNamespace("DBI")) %>%
 #   grep("^db[A-Z]", ., value = TRUE) %>%
-#   setdiff(c("dbCallProc", "dbListConnections", "dbSetDataMappings")) %>%
+#   setdiff(c("dbCallProc", "dbListConnections", "dbSetDataMappings", "dbGetException")) %>%
 #   paste0("#' @exportMethod ", ., "\nNULL\n", collapse = "\n") %>%
 #   cat(file = "R/export.R")
+#' @exportMethod dbAppendTable
+NULL
 
 #' @exportMethod dbBegin
 NULL
@@ -11,6 +13,9 @@ NULL
 #' @exportMethod dbBind
 NULL
 
+#' @exportMethod dbCanConnect
+NULL
+
 #' @exportMethod dbClearResult
 NULL
 
@@ -23,6 +28,9 @@ NULL
 #' @exportMethod dbConnect
 NULL
 
+#' @exportMethod dbCreateTable
+NULL
+
 #' @exportMethod dbDataType
 NULL
 
@@ -41,9 +49,6 @@ NULL
 #' @exportMethod dbFetch
 NULL
 
-#' @exportMethod dbGetException
-NULL
-
 #' @exportMethod dbGetInfo
 NULL
 
@@ -62,12 +67,18 @@ NULL
 #' @exportMethod dbHasCompleted
 NULL
 
+#' @exportMethod dbIsReadOnly
+NULL
+
 #' @exportMethod dbIsValid
 NULL
 
 #' @exportMethod dbListFields
 NULL
 
+#' @exportMethod dbListObjects
+NULL
+
 #' @exportMethod dbListResults
 NULL
 
@@ -77,6 +88,12 @@ NULL
 #' @exportMethod dbQuoteIdentifier
 NULL
 
+#' @exportMethod dbQuoteLiteral
+NULL
+
+#' @exportMethod dbQuoteLiteral
+NULL
+
 #' @exportMethod dbQuoteString
 NULL
 
@@ -98,8 +115,14 @@ NULL
 #' @exportMethod dbUnloadDriver
 NULL
 
+#' @exportMethod dbUnquoteIdentifier
+NULL
+
 #' @exportMethod dbWithTransaction
 NULL
 
 #' @exportMethod dbWriteTable
 NULL
+
+#' @export
+DBI::Id
