@@ -1,10 +1,10 @@
 #ifndef RSQLITE_SQLITERESULTIMPL_H
 #define RSQLITE_SQLITERESULTIMPL_H
 
-
+#include <cpp11.hpp>
 #include <boost/noncopyable.hpp>
 #include <boost/shared_ptr.hpp>
-#include "sqlite3.h"
+#include "sqlite3-cpp.h"
 #include "DbColumnDataType.h"
 
 class DbConnection;
@@ -32,7 +32,7 @@ private:
   bool ready_;
   int nrows_;
   int total_changes_start_;
-  List params_;
+  cpp11::list params_;
   int group_, groups_;
   std::vector<DATA_TYPE> types_;
   bool with_alt_types_;
@@ -51,25 +51,25 @@ public:
   bool complete() const;
   int n_rows_fetched();
   int n_rows_affected();
-  void bind(const List& params);
-  List fetch(const int n_max);
+  void bind(const cpp11::list& params);
+  cpp11::list fetch(const int n_max);
 
-  List get_column_info();
+  cpp11::list get_column_info();
 
 public:
-  CharacterVector get_placeholder_names() const;
+  cpp11::strings get_placeholder_names() const;
 
 private:
-  void set_params(const List& params);
+  void set_params(const cpp11::list& params);
   bool bind_row();
   void bind_parameter_pos(int j, SEXP value_);
   void after_bind(bool params_have_rows);
 
-  List fetch_rows(int n_max, int& n);
+  cpp11::list fetch_rows(int n_max, int& n);
   void step();
   bool step_run();
   bool step_done();
-  List peek_first_row();
+  cpp11::list peek_first_row();
 
 private:
   void NORET raise_sqlite_exception() const;
